==> sagemaker-0.25.3-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstance.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstance.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-12T14:21:34.723Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnNotebookInstance")
public class CfnNotebookInstance extends software.amazon.awscdk.Resource {
    protected CfnNotebookInstance(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.sagemaker.CfnNotebookInstance.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::SageMaker::NotebookInstance``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnNotebookInstance(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getNotebookInstanceArn() {
        return this.jsiiGet("notebookInstanceArn", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute NotebookInstanceName
     */
    public java.lang.String getNotebookInstanceName() {
        return this.jsiiGet("notebookInstanceName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps.class);
    }

    /**
     * The ``TagManager`` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. ``Tag`` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
}

==> sagemaker-0.26.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstance.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * @cloudformationResource AWS::SageMaker::NotebookInstance
 * A CloudFormation `AWS::SageMaker::NotebookInstance`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstance.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:56:22.273Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnNotebookInstance")
public class CfnNotebookInstance extends software.amazon.awscdk.CfnResource {
    protected CfnNotebookInstance(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.sagemaker.CfnNotebookInstance.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::SageMaker::NotebookInstance`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnNotebookInstance(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getNotebookInstanceArn() {
        return this.jsiiGet("notebookInstanceArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute NotebookInstanceName
     */
    public java.lang.String getNotebookInstanceName() {
        return this.jsiiGet("notebookInstanceName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
}
